@@ -1,7 +1,9 @@
 from json import loads
 import os
 import sys
+import pathlib
 
+print("0" + pathlib.Path(__file__).parent.absolute())
 print("1" + os.path.dirname(os.path.realpath(__file__)))
 print("2" + sys.path[0])
 print("3" + os.path.dirname(os.path.realpath(sys.argv[0])))
